Index: components/content_settings/core/browser/website_settings_info.h |
diff --git a/components/content_settings/core/browser/website_settings_info.h b/components/content_settings/core/browser/website_settings_info.h |
index 762e32e828c4e52f58a802817d527fdb920a9297..049a31beb65ef14244794624421fd66cf89342b8 100644 |
--- a/components/content_settings/core/browser/website_settings_info.h |
+++ b/components/content_settings/core/browser/website_settings_info.h |
@@ -27,12 +27,8 @@ class WebsiteSettingsInfo { |
enum LossyStatus { LOSSY, NOT_LOSSY }; |
enum ScopingType { |
- // Settings scoped to the domain of the main frame only. |
- TOP_LEVEL_DOMAIN_ONLY_SCOPE, |
- |
- // Settings scoped to the domain of the requesting frame only. This should |
- // not generally be used. |
- REQUESTING_DOMAIN_ONLY_SCOPE, |
+ // Settings scoped to the origin of the main frame only. |
+ TOP_LEVEL_ORIGIN_ONLY_SCOPE, |
// Settings scoped to the origin of the requesting frame only. |
REQUESTING_ORIGIN_ONLY_SCOPE, |